@@ -1,7 +1,7 @@
 // qmidinet.cpp
 //
 /****************************************************************************
-   Copyright (C) 2010-2021, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2010-2022, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -46,7 +46,7 @@ qmidinetApplication::qmidinetApplication ( int& argc, char **argv, bool bGUI )
 		, m_udpd(this)
 {
 	if (bGUI) {
-	#if defined(Q_OS_LINUX)
+	#if defined(Q_OS_LINUX) && !defined(CONFIG_WAYLAND)
 		::setenv("QT_QPA_PLATFORM", "xcb", 0);
 	#endif
 	#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
@@ -58,6 +58,17 @@ qmidinetApplication::qmidinetApplication ( int& argc, char **argv, bool bGUI )
 	#if QT_VERSION >= QT_VERSION_CHECK(5, 1, 0)
 		pApp->setApplicationDisplayName(QMIDINET_TITLE);
 		//	QMIDINET_TITLE " - " + QObject::tr(QMIDINET_SUBTITLE));
+	#if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
+		pApp->setDesktopFileName(
+			QString("org.rncbc.%1").arg(PACKAGE_TARNAME));
+	#endif
+		QString sVersion(CONFIG_BUILD_VERSION);
+		sVersion += '\n';
+		sVersion += QString("Qt: %1").arg(qVersion());
+	#if defined(QT_STATIC)
+		sVersion += "-static";
+	#endif
+		pApp->setApplicationVersion(sVersion);
 	#endif
 		pApp->setQuitOnLastWindowClosed(false);
 		m_pApp  = pApp;
@@ -226,7 +237,7 @@ void qmidinetApplication::shutdown (void)
 qmidinetSystemTrayIcon::qmidinetSystemTrayIcon ( qmidinetApplication *pApp )
 	: QSystemTrayIcon(pApp), m_pApp(pApp), m_iSending(0), m_iReceiving(0)
 {
-//	m_menu.addAction(QIcon(":/images/qmidinet.png"), QMIDINET_TITLE);
+//	m_menu.addAction(QIcon(":/images/qmidinet.svg"), QMIDINET_TITLE);
 //	m_menu.addSeparator();
 	m_menu.addAction(QIcon(":/images/menuOptions.png"),
 		tr("Options..."), this, SLOT(options()));
@@ -351,7 +362,8 @@ void qmidinetSystemTrayIcon::about (void)
 	QMessageBox abox;
 	abox.setWindowIcon(QSystemTrayIcon::icon());
 	abox.setWindowTitle(tr("About"));
-	abox.setIconPixmap(QPixmap(":/images/qmidinet.png"));
+	abox.setIconPixmap(QPixmap(":/images/qmidinet.svg")
+		.scaledToWidth(48, Qt::SmoothTransformation));
 	abox.setText(sText);
 	abox.exec();
 }
