@@ -1,7 +1,7 @@
 // qmidinetOptionsForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2010-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2010-2022, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -40,7 +40,9 @@ qmidinetOptionsForm::qmidinetOptionsForm ( QWidget *pParent )
 {
 	// Setup UI struct...
 	m_ui.setupUi(this);
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 1, 0)
+	QDialog::setWindowIcon(QIcon(":/images/qmidinet.png"));
+#endif
 	// Initialize the dialog widgets with default settings...
 	m_sDefInterface = tr("(Any)");
 	m_ui.InterfaceComboBox->clear();
